@@ -2,13 +2,23 @@ var config = module.exports;
 
 config.browser_tests = {
     environment: "browser",
-    libs: ["test/lib/*.js"],
+    libs: [
+        "lib/bane-*.js",
+        "lib/when-define-shim.js",
+        "lib/when-*.js"
+    ],
+    sources: ["src/**/*.js"],
     testHelpers: ["test/**/*-helper.js"],
     tests: ["test/**/*-test.js"]
 };
 
 config.node_tests = {
     environment: "node",
+    libs: [
+        "lib/bane-*.js",
+        "lib/when-define-shim.js",
+        "lib/when-*.js"
+    ],
     sources: ["src/**/*.js"],
     testHelpers: ["test/**/*-helper.js"],
     tests: ["test/**/*-test.js"]
